Documentation
¶
Overview ¶
Package memory provides an in-memory implementation of the lockbox.dev/clients.Storer interface.
This implementation is useful for testing and demo setups in which data is not meant to be stored reliably or for a long time. All the data will be permanently lost when the service process exits.
Index ¶
- type Factory
- type Storer
- func (s Storer) AddRedirectURIs(ctx context.Context, uris []clients.RedirectURI) error
- func (s Storer) Create(ctx context.Context, client clients.Client) error
- func (s Storer) Delete(ctx context.Context, id string) error
- func (s Storer) Get(ctx context.Context, id string) (clients.Client, error)
- func (s Storer) ListRedirectURIs(ctx context.Context, clientID string) ([]clients.RedirectURI, error)
- func (s Storer) RemoveRedirectURIs(ctx context.Context, uris []string) error
- func (s Storer) Update(ctx context.Context, id string, change clients.Change) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Storer ¶
type Storer struct {
// contains filtered or unexported fields
}
Storer is an in-memory implementation of the Storer interface.
func (Storer) AddRedirectURIs ¶
func (Storer) ListRedirectURIs ¶
func (Storer) RemoveRedirectURIs ¶
Click to show internal directories.
Click to hide internal directories.